#[repr(C)]pub struct CoordinatorCreateLayerRequest {
pub layer_id: LayerId,
}Fields
layer_id: LayerIdTrait Implementations
Sourceimpl Clone for CoordinatorCreateLayerRequest
impl Clone for CoordinatorCreateLayerRequest
Sourcefn clone(&self) -> CoordinatorCreateLayerRequest
fn clone(&self) -> CoordinatorCreateLayerRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<CoordinatorCreateLayerRequest, D> for CoordinatorCreateLayerRequest
impl<D: ResourceDialect> Decode<CoordinatorCreateLayerRequest, D> for CoordinatorCreateLayerRequest
Sourceimpl<D: ResourceDialect> Encode<CoordinatorCreateLayerRequest, D> for &CoordinatorCreateLayerRequest
impl<D: ResourceDialect> Encode<CoordinatorCreateLayerRequest, D> for &CoordinatorCreateLayerRequest
Sourceimpl<D: ResourceDialect, T0: Encode<LayerId, D>> Encode<CoordinatorCreateLayerRequest, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<LayerId, D>> Encode<CoordinatorCreateLayerRequest, D> for (T0,)
Sourceimpl Hash for CoordinatorCreateLayerRequest
impl Hash for CoordinatorCreateLayerRequest
Sourceimpl Ord for CoordinatorCreateLayerRequest
impl Ord for CoordinatorCreateLayerRequest
Sourcefn cmp(&self, other: &CoordinatorCreateLayerRequest) -> Ordering
fn cmp(&self, other: &CoordinatorCreateLayerRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CoordinatorCreateLayerRequest
impl PartialEq for CoordinatorCreateLayerRequest
Sourcefn eq(&self, other: &CoordinatorCreateLayerRequest) -> bool
fn eq(&self, other: &CoordinatorCreateLayerRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for CoordinatorCreateLayerRequest
impl PartialOrd for CoordinatorCreateLayerRequest
Sourceimpl TypeMarker for CoordinatorCreateLayerRequest
impl TypeMarker for CoordinatorCreateLayerRequest
Sourcetype Owned = CoordinatorCreateLayerRequest
type Owned = CoordinatorCreateLayerRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for CoordinatorCreateLayerRequest
impl ValueTypeMarker for CoordinatorCreateLayerRequest
Sourcetype Borrowed<'a> = &'a CoordinatorCreateLayerRequest
type Borrowed<'a> = &'a CoordinatorCreateLayerRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Copy for CoordinatorCreateLayerRequest
impl Eq for CoordinatorCreateLayerRequest
impl Persistable for CoordinatorCreateLayerRequest
impl StructuralPartialEq for CoordinatorCreateLayerRequest